@@ -24,8 +24,11 @@ __version__ = pkg_resources.resource_string(
 # exported.
 from lazr.enum._enum import *
 from lazr.enum._enum import __all__ as _all
+from lazr.enum._json import *
+from lazr.enum._json import __all__ as _jall
 from lazr.enum.interfaces import *
 from lazr.enum.interfaces import __all__ as _iall
 __all__ = []
 __all__.extend(_all)
 __all__.extend(_iall)
+__all__.extend(_jall)
