@@ -4,8 +4,7 @@
 #
 # lazr.enum is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or (at your
-# option) any later version.
+# the Free Software Foundation, version 3 of the License.
 #
 # lazr.enum is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -17,20 +16,6 @@
 
 __metaclass__ = type
 
-import itertools
-import operator
-import sys
-import warnings
-
-from zope.interface import implements
-from zope.schema.interfaces import ITitledTokenizedTerm, IVocabularyTokenized
-try:
-    from zope.proxy import removeAllProxies
-except ImportError:
-    removeAllProxies = lambda obj: obj # no-op
-
-from lazr.enum.interfaces import IEnumeratedType
-
 __all__ = [
     'BaseItem',
     'DBEnumeratedType',
@@ -46,6 +31,21 @@ __all__ = [
     'MetaDBEnum', # needed for configure.zcml
     ]
 
+import itertools
+import operator
+import sys
+import warnings
+
+from zope.interface import implements
+from zope.schema.interfaces import ITitledTokenizedTerm, IVocabularyTokenized
+try:
+    from zope.proxy import removeAllProxies
+except ImportError:
+    removeAllProxies = lambda obj: obj # no-op
+
+from lazr.enum.interfaces import IEnumeratedType
+
+
 def proxy_isinstance(obj, cls):
     """Test whether an object is an instance of a type.
 
@@ -54,6 +54,7 @@ def proxy_isinstance(obj, cls):
     """
     return isinstance(removeAllProxies(obj), cls)
 
+
 def docstring_to_title_descr(string):
     """When given a classically formatted docstring, returns a tuple
     (title, description).
@@ -97,8 +98,8 @@ def docstring_to_title_descr(string):
             break
     else:
         raise ValueError
-    assert not lines[num+1].strip()
-    descrlines = lines[num+2:]
+    assert not lines[num + 1].strip()
+    descrlines = lines[num + 2:]
     descr1 = descrlines[0]
     indent = len(descr1) - len(descr1.lstrip())
     descr = '\n'.join([line[indent:] for line in descrlines])
@@ -163,6 +164,12 @@ class BaseItem:
                 stacklevel=stacklevel)
             return False
         elif proxy_isinstance(other, BaseItem):
+            if (not getattr(self, 'enum', None)
+                or not getattr(other, 'enum', None)):
+                warnings.warn('comparison of Items which are not '
+                              'enumerated types',
+                    stacklevel=stacklevel)
+                return False
             return (self.name == other.name and
                     self.enum == other.enum)
         else:
@@ -201,7 +208,7 @@ class DBItem(BaseItem):
     @staticmethod
     def construct(other_item):
         """Create an Item based on the other_item."""
-        item = DBItem(other_item.value, other_item.title, 
+        item = DBItem(other_item.value, other_item.title,
                       other_item.description, other_item.url)
         item.sortkey = other_item.sortkey
         return item
@@ -253,13 +260,16 @@ class EnumItems:
     def __init__(self, items, mapping):
         self.items = items
         self.mapping = mapping
+
     def __getitem__(self, key):
         if key in self.mapping:
             return self.mapping[key]
         else:
             raise KeyError(key)
+
     def __iter__(self):
         return self.items.__iter__()
+
     def __len__(self):
         return len(self.items)
 
